User Documentation - MindRoot 9.10.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# User Documentation

This section covers everything you need to get started with MindRoot as a user.

Test

Contents:

- Installation
- Starting MindRoot
- LLM Plugin Installation
- LLM API Key
- Chat with Assistant
- Install Plugins with Tools
- Give Assistant a Programming Task
- Embed Agent Chat on Your Website
  - Create an API Key
  - Disable Chat Avatar on Left
  - Get Chat Widget Embed Code
  - Insert into HTML